@@ -16,7 +16,7 @@ public abstract class Config
 	private static File _configFile = null;
 
 	/** Hashtable containing all config values */
-	private static Properties _configValues = new Properties();
+	private static Properties _configValues = null;
 	/** Colour scheme object is also part of config */
 	private static ColourScheme _colourScheme = new ColourScheme();
 	/** Recently-used file list */
@@ -76,6 +76,12 @@ public abstract class Config
 	public static final String KEY_RECENT_FILES = "prune.recentfiles";
 
 
+	/** Initialise the default properties */
+	static
+	{
+		_configValues = getDefaultProperties();
+	}
+
 	/**
 	 * Load the default configuration file
 	 */
