@@ -67,7 +67,7 @@ public abstract class MapSource
 	 */
 	public String makeFilePath(int inLayerNum, int inZoom, int inX, int inY)
 	{
-		return getSiteName(inLayerNum) + inZoom + "/" + inX + "/" + inY + getFileExtension(inLayerNum);
+		return getSiteName(inLayerNum) + inZoom + "/" + inX + "/" + inY + "." + getFileExtension(inLayerNum);
 	}
 
 	/**
