@@ -24,6 +24,10 @@ public class MapTileManager implements ImageObserver
 	private int _numLayers = -1;
 	/** Current zoom level */
 	private int _zoom = 0;
+	/** Currently blocked zoom level, to prevent looping for non-existent images */
+	private int _blockedZoom = 0;
+	/** Number of tiles in each direction for this zoom level */
+	private int _numTileIndices = 1;
 
 
 	/**
@@ -47,6 +51,8 @@ public class MapTileManager implements ImageObserver
 	public void centreMap(int inZoom, int inTileX, int inTileY)
 	{
 		_zoom = inZoom;
+		// Calculate number of tiles = 2^^zoom
+		_numTileIndices = 1 << _zoom;
 		// Pass params onto all memory cachers
 		if (_tempCaches != null) {
 			for (int i=0; i<_tempCaches.length; i++) {
@@ -135,6 +141,9 @@ public class MapTileManager implements ImageObserver
 	 */
 	public Image getTile(int inLayer, int inX, int inY)
 	{
+		// Check tile boundaries
+		if (inX < 0 || inX >= _numTileIndices || inY < 0 || inY >= _numTileIndices) return null;
+
 		// Check first in memory cache for tile
 		MemTileCacher tempCache = _tempCaches[inLayer]; // Should probably guard against nulls and array indexes here
 		Image tile = tempCache.getTile(inX, inY);
@@ -158,8 +167,9 @@ public class MapTileManager implements ImageObserver
 			}
 		}
 		// Tile wasn't in memory or on disk, so if online let's get it
-		if (onlineMode)
+		if (onlineMode && _blockedZoom != _zoom)
 		{
+			_blockedZoom = 0; // reset to try again
 			try
 			{
 				URL tileUrl = new URL(_mapSource.makeURL(inLayer, _zoom, inX, inY));
@@ -196,6 +206,9 @@ public class MapTileManager implements ImageObserver
 	{
 		boolean loaded = (infoflags & ImageObserver.ALLBITS) > 0;
 		boolean error = (infoflags & ImageObserver.ERROR) > 0;
+		if (error) {
+			_blockedZoom = _zoom;
+		}
 		if (loaded || error) {
 			_parent.tilesUpdated(loaded);
 		}
